<?php

namespace Drupal\views_filter_not_front\Plugin\views\filter;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Routing\Router;
use Drupal\node\Entity\Node;
use Drupal\views\Plugin\views\display\DisplayPluginBase;
use Drupal\views\Plugin\views\filter\FilterPluginBase;
use Drupal\views\ViewExecutable;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Exclude front page if it is a node
 *
 * @ingroup views_filter_handlers
 *
 * @ViewsFilter("not_front")
 */
class NotFront extends FilterPluginBase {

  /**
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * @var \Drupal\Core\Routing\Router
   */
  protected $router;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ConfigFactoryInterface $config_factory, Router $router) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configFactory = $config_factory;
    $this->router = $router;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory'),
      $container->get('router.no_access_checks')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
    parent::init($view, $display, $options);

    $this->value = FALSE;
    $this->operator = "<>";
    $this->no_operator = TRUE;

    $frontpage_url = $this->configFactory->get('system.site')->get('page.front');

    try {
      $route = $this->router->match($frontpage_url);
    }
    catch (\Exception $e) {

    }

    if (isset($route['node']) && $route['node'] instanceof Node) {
      $this->value = $route['node']->nid->value;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function canExpose() {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
    if ($this->value) {
      parent::query();
    }
  }

}